joop.cli.test_flask — joop 0.0.1 documentation

# joop.cli.test_flask

Flask testing module for joop.

This module provides functionality to start a Flask webserver for testing and development purposes.

Important: The test joop env is set as the jinja env for the Flask server. This is specific and desirable

  though your project may implement the environment otherwise.

Functions:
  start_test_flask():

    Starts the Flask webserver in debug mode using the app instance from joop.flask.

Dependencies:

  - Flask: Ensure Flask is installed. If not, install it using pip install joop[flask].

Usage:

  - Import the start_test_flask function and call it to start the Flask webserver.

Functions

`start_test_flask`() |

joop.cli.test_flask.start_test_flask()